Enum netcorehost::hostfxr::HostExitCode [−][src]
pub enum HostExitCode {
Known(KnownHostExitCode),
Unknown(u32),
}Expand description
Represents an exit code from a hostfxr operation.
This may be one of the special code from KnownHostExitCode,
the exit code of the application or an error code resulting from violating
some unchecked hostfxr constraint.
Variants
Tuple Fields of Known
Tuple Fields of Unknown
0: u32Implementations
Returns a value indicating whether the exit code represents a successful operation.
Returns a value indicating whether the exit code represents an error.